Release Notes
=============

The list of changes to openwillis between each release can be found
[here](https://github.com/bklynhlth/openwillis). For full
details, see the commit logs at https://github.com/bklynhlth/openwillis.